==> sweepinconnect-2.0.6-sources.jar: com/proximities/sdk/adapter/MultiCampaignsAdapter.java <==
package com.proximities.sdk.adapter;

import android.content.Context;
import android.graphics.Bitmap;
import android.support.v4.graphics.drawable.RoundedBitmapDrawable;
import android.support.v4.graphics.drawable.RoundedBitmapDrawableFactory;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import com.bumptech.glide.Glide;
import com.bumptech.glide.request.target.BitmapImageViewTarget;
import com.proximities.sdk.ProximitiesConfig;
import com.proximities.sdk.R;
import com.proximities.sdk.json.model.transmitter.Campaign;
import com.proximities.sdk.util.ProximitiesConstants;

import java.util.ArrayList;
import java.util.List;

/**
 * Created by william on 23/06/15.
 */
public class MultiCampaignsAdapter extends BaseAdapter{

    private Context ctx;
    private List<Campaign> campaigns;
    private LayoutInflater inflater;

    public MultiCampaignsAdapter(Context context, List<Campaign> campaigns) {
        this.ctx = context;
        if (campaigns == null) {
            this.campaigns = new ArrayList<>();
        } else {
            this.campaigns = campaigns;
        }
        inflater = LayoutInflater.from(this.ctx);
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        final AnimViewHolder holder;
        if (convertView == null) {
            convertView = inflater.inflate(R.layout.prxsc_animation_list_item, parent, false);
            holder = new AnimViewHolder(convertView);
            convertView.setTag(holder);
        } else {
            holder = (AnimViewHolder) convertView.getTag();
        }

        Campaign anim = getItem(position);
        if(anim.getImage() != null && !anim.getImage().isEmpty()){
            Glide.with(ctx).load(ProximitiesConstants.STATIC_CONTENT_HOST + anim.getImage()).asBitmap().thumbnail(0.1f).into(new BitmapImageViewTarget(holder.image) {
                @Override
                protected void setResource(Bitmap resource) {
                    RoundedBitmapDrawable circularBitmapDrawable = RoundedBitmapDrawableFactory.create(ctx.getResources(), resource);
                    circularBitmapDrawable.setCircular(true);
                    holder.image.setImageDrawable(circularBitmapDrawable);
                }
            });
        } else {
            int resource = android.R.color.transparent;
            switch(anim.getTemplateType()){
                case ProximitiesConfig.SIMPLE_CAMPAIGN:
                    resource = R.drawable.prxsc_default_notif_simple;
                    break;
                case ProximitiesConfig.RICH_CAMPAIGN:
                    resource = R.drawable.prxsc_default_notif_rich;
                    break;
                case ProximitiesConfig.AUDIO_CAMPAIGN:
                    resource = R.drawable.prxsc_default_notif_audio;
                    break;
                case ProximitiesConfig.WEB_CAMPAIGN:
                    resource = R.drawable.prxsc_default_notif_webview;
                    break;
        }
        Glide.with(ctx).load(resource).asBitmap().into(holder.image);

    }
        holder.poiName.setText(anim.getPoi().getName());
        holder.content.setText(anim.getTitle());
        return convertView;
    }

    @Override
    public Campaign getItem(int position) {
        return campaigns.get(position);
    }

    @Override
    public long getItemId(int position) {
        return 0;
    }

    @Override
    public int getCount() {
        return campaigns.size();
    }

    private class AnimViewHolder {
        ImageView image;
        TextView poiName;
        TextView content;

        public AnimViewHolder(View item) {
            image = (ImageView) item.findViewById(R.id.image);
            poiName = (TextView) item.findViewById(R.id.poi_name);
            content = (TextView) item.findViewById(R.id.content);
        }
    }


}

==> sweepinconnect-2.1.0-sources.jar: com/proximities/sdk/adapter/MultiCampaignsAdapter.java <==
package com.proximities.sdk.adapter;

import android.content.Context;
import android.graphics.Bitmap;
import androidx.core.graphics.drawable.RoundedBitmapDrawable;
import androidx.core.graphics.drawable.RoundedBitmapDrawableFactory;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import com.bumptech.glide.Glide;
import com.bumptech.glide.request.target.BitmapImageViewTarget;
import com.proximities.sdk.ProximitiesConfig;
import com.proximities.sdk.R;
import com.proximities.sdk.json.model.transmitter.Campaign;
import com.proximities.sdk.util.ProximitiesConstants;

import java.util.ArrayList;
import java.util.List;

/**
 * Created by william on 23/06/15.
 */
public class MultiCampaignsAdapter extends BaseAdapter{

    private Context ctx;
    private List<Campaign> campaigns;
    private LayoutInflater inflater;

    public MultiCampaignsAdapter(Context context, List<Campaign> campaigns) {
        this.ctx = context;
        if (campaigns == null) {
            this.campaigns = new ArrayList<>();
        } else {
            this.campaigns = campaigns;
        }
        inflater = LayoutInflater.from(this.ctx);
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        final AnimViewHolder holder;
        if (convertView == null) {
            convertView = inflater.inflate(R.layout.prxsc_animation_list_item, parent, false);
            holder = new AnimViewHolder(convertView);
            convertView.setTag(holder);
        } else {
            holder = (AnimViewHolder) convertView.getTag();
        }

        Campaign anim = getItem(position);
        if(anim.getImage() != null && !anim.getImage().isEmpty()){
            Glide.with(ctx).load(ProximitiesConstants.STATIC_CONTENT_HOST + anim.getImage()).asBitmap().thumbnail(0.1f).into(new BitmapImageViewTarget(holder.image) {
                @Override
                protected void setResource(Bitmap resource) {
                    RoundedBitmapDrawable circularBitmapDrawable = RoundedBitmapDrawableFactory.create(ctx.getResources(), resource);
                    circularBitmapDrawable.setCircular(true);
                    holder.image.setImageDrawable(circularBitmapDrawable);
                }
            });
        } else {
            int resource = android.R.color.transparent;
            switch(anim.getTemplateType()){
                case ProximitiesConfig.SIMPLE_CAMPAIGN:
                    resource = R.drawable.prxsc_default_notif_simple;
                    break;
                case ProximitiesConfig.RICH_CAMPAIGN:
                    resource = R.drawable.prxsc_default_notif_rich;
                    break;
                case ProximitiesConfig.AUDIO_CAMPAIGN:
                    resource = R.drawable.prxsc_default_notif_audio;
                    break;
                case ProximitiesConfig.WEB_CAMPAIGN:
                    resource = R.drawable.prxsc_default_notif_webview;
                    break;
        }
        Glide.with(ctx).load(resource).asBitmap().into(holder.image);

    }
        holder.poiName.setText(anim.getPoi().getName());
        holder.content.setText(anim.getTitle());
        return convertView;
    }

    @Override
    public Campaign getItem(int position) {
        return campaigns.get(position);
    }

    @Override
    public long getItemId(int position) {
        return 0;
    }

    @Override
    public int getCount() {
        return campaigns.size();
    }

    private class AnimViewHolder {
        ImageView image;
        TextView poiName;
        TextView content;

        public AnimViewHolder(View item) {
            image = (ImageView) item.findViewById(R.id.image);
            poiName = (TextView) item.findViewById(R.id.poi_name);
            content = (TextView) item.findViewById(R.id.content);
        }
    }


}
